set_unix_socket_write_only

Function set_unix_socket_write_only 

pub async fn set_unix_socket_write_only<P: AsRef<Path>>(path: P) -> Result<()>
Sets the UNIX socket at the given path to be write-only by non-owners.

This ensures that normal clients can write to the socket but not read from it.

Errors

If the underlying system call fails, an error is returned.