pub async fn ensure_unix_socket_free<P: AsRef<Path>>(path: P) -> Result<()>Expand description
Ensures that the given path is read for use as a UNIX socket.
If the path already exists, and is a UNIX socket, it will be removed. If it’s not a UNIX socket, an error will be returned.
Errors
If the underlying system call fails, an error is returned.